from sqlite_utils import Database

from casedb.views import (
    DuplicateCitations,
    PopularCitations,
    missing_ponentes,
    missing_rulings,
    scra_dockets,
    short_titles,
)

from .decision_tables import (
    annotations,
    case_statutes,
    citations,
    decisions,
    identifiers,
    provisions,
    segments,
    titles,
)
from .statute_tables import containers, statutes, units


def setup_tables(db: Database) -> Database:
    db = statutes(db)
    db = units(db)
    db = containers(db)
    db = identifiers(db)
    db = decisions(db)
    db = citations(db)
    db = segments(db)
    db = annotations(db)
    db = case_statutes(db)
    db = provisions(db)
    db = titles(db)
    db = create_views(db)

    return db


def create_views(db: Database) -> Database:

    if "citations_with_scra_dockets" not in db.view_names():  # see source file
        db.create_view(name="citations_with_scra_dockets", sql=scra_dockets)

    if "shorter_case_titles" not in db.view_names():  # Citations to Titles
        db.create_view(name="shorter_case_titles", sql=short_titles)

    if "missing_rulings" not in db.view_names():  # field missing
        db.create_view(name="missing_rulings", sql=missing_rulings)

    if "missing_ponentes" not in db.view_names():  # field missing
        db.create_view(name="missing_ponentes", sql=missing_ponentes)

    # use for debugging
    # for dup in DuplicateCitations:  # check Decisions if duplicate Citations
    #    if dup.name not in db.view_names():
    #        db.create_view(*dup.shortcut)

    for popular in PopularCitations:  # get most referenced Citations
        if popular.name not in db.view_names():
            db.create_view(*popular.shortcut)

    return db
