from sqlite_utils import Database

from casedb.sql.update_uncited_titles import uncited_sql, update_uncited_titles


def inserted_title_updater(db: Database, idx: int):
    """
    Get uncited Titles that can be matched with a cited Title. The cited Title should be unique in terms of plaintiff / defendant. This results in an Iterator[Tuple] with format: (plaintiff, defendant, cited Title id)
    Each uncited pairings of plaintiff / defendants (even with same decision id "idx") have different pks since these originate from different segments.
    Since each tuple contains a correct cited Title id, bulk update each pairing with cited Title details from the cited Title id.
    """
    for i in db.execute(uncited_sql, {"decision_id": idx}):
        cols = "citation, docket, phil, scra, offg"
        cited = next(db["Titles"].rows_where("id = ?", (i[2],), select=cols))
        content = {
            "citation": cited["citation"],
            "docket": cited["docket"],
            "phil": cited["phil"],
            "scra": cited["scra"],
            "offg": cited["offg"],
            "decision_id": idx,
            "plaintiff": i[0],
            "defendant": i[1],
        }
        db.execute(update_uncited_titles, content)
    return db
