"""
1. Input: a `phil` from data dict
2. Get existing `phil` from Phils
3. Use existing `phil` to look for matching Decision via Phils.id
4. If a match is found, return row of:
    1. Dockets.docket
    2. Phils.phil
    3. Decisions.id
5. Can now compare the data dict `docket` with Dockets.docket
"""
input_phil_sql = """
--sql
select
    dkt.docket, p.phil, d.id
from
    Phils p
    join Decisions d on d.phil = p.id
    join Dockets dkt on d.docket = dkt.id
where
    p.phil = ?
;
"""


"""
1. Assume the data dict `docket` is NOT THE SAME as the Dockets.docket above
2. This means that the data dict is a decision that is different from existing record
3. This function enable the assignment of NULL to the existing Decision phil field
4. The data dict `phil` should likewise be assigned to NULL (outside this sql)
5. This method, albeit inefficient, ensures no duplicate Decision phil fields
"""
null_decision_phil = """
--sql
update
    Decisions
set
    phil = NULL
where
    phil = (
        select p.id
        from Phils p
        where p.phil = ?
    )
;
"""
