"""
1. Get all Titles
2. Look for Titles with missing identifiers, i.e. docket, scra, phil, offg
3. These Titles must have plaintiffs and defendants
4. These Titles must, in the same decision, have a corresponding Title that contains identifiers
5. But only match identifiers that have unique plaintiff and defendant
6. Meaning if there are plaintiff - defendant pairings that are not unique, do not match
7. The resulting sql query will be a tuple of: plaintiff, defendant, matching Title ID
"""
uncited_sql = f"""
--sql
select
    t.plaintiff,
    t.defendant,
    (
        select t1.id
        from Titles t1
        where (
            t1.plaintiff = t.plaintiff
            and t1.defendant = t.defendant
            and t1.decision_id = :decision_id
            and (
                t1.docket is not null
                or t1.scra is not null
                or t1.phil is not null
                or t1.offg is not null
            )
        )
        group by t1.plaintiff, t1.defendant
        having count(t1.plaintiff) = 1 and count(t1.defendant) = 1
    ) cited_title_id
from
    Titles t
where
    t.decision_id = :decision_id
    and t.updated = 0
    and t.plaintiff is not null
    and t.defendant is not null
    and (
        t.docket is null
        and t.phil is null
        and t.scra is null
        and t.offg is null
    )
group by
    t.plaintiff, t.defendant
having
    cited_title_id is not null;
"""


update_uncited_titles = """
--sql
update
    Titles
set
    citation = :citation,
    docket = :docket,
    phil = :phil,
    scra = :scra,
    offg = :offg,
    updated = 1
where
    decision_id = :decision_id
    and plaintiff = :plaintiff
    and defendant = :defendant
"""
